@@ -2,9 +2,7 @@
 # child processes and @in-process
 unless RUBY_PLATFORM.include?('java')
   require 'simplecov'
-
-  root = File.expand_path('../../../', __FILE__)
-
+  root = File.expand_path('../..', __dir__)
   SimpleCov.command_name(ENV['SIMPLECOV_COMMAND_NAME'])
   SimpleCov.root(root)
   load File.join(root, '.simplecov')
