@@ -14,7 +14,14 @@ module Aruba
       # @param [#to_s] text
       #   Input
       def unescape_text(text)
-        text.gsub('\n', "\n").gsub('\"', '"').gsub('\e', "\e").gsub('\033', "\e").gsub('\016', "\016").gsub('\017', "\017").gsub('\t', "\t")
+        text
+          .gsub('\n', "\n")
+          .gsub('\"', '"')
+          .gsub('\e', "\e")
+          .gsub('\033', "\e")
+          .gsub('\016', "\016")
+          .gsub('\017', "\017")
+          .gsub('\t', "\t")
       end
 
       # Remove ansi characters from text
@@ -22,11 +29,10 @@ module Aruba
       # @param [#to_s] text
       #   Input
       def extract_text(text)
-        if Aruba::VERSION < '1'
-          text.gsub(/(?:\e|\033)\[\d+(?>(;\d+)*)m/, '')
-        else
-          text.gsub(/(?:\e|\033)\[\d+(?>(;\d+)*)m/, '').gsub(/\\\[|\\\]/, '').gsub(/\007|\016|\017/, '')
-        end
+        text
+          .gsub(/(?:\e|\033)\[\d+(?>(;\d+)*)m/, '')
+          .gsub(/\\\[|\\\]/, '')
+          .gsub(/\007|\016|\017/, '')
       end
 
       # Unescape special characters and remove ANSI characters
@@ -35,19 +41,19 @@ module Aruba
       #   The text to sanitize
       def sanitize_text(text)
         text = unescape_text(text)
-        text = extract_text(text) if !aruba.config.keep_ansi || aruba.config.remove_ansi_escape_sequences
+        text = extract_text(text) if aruba.config.remove_ansi_escape_sequences
 
         text.chomp
       end
 
-      # @experimental
-      #
-      # Replace variables in command string
+      # Replace variables in command string (experimental)
       #
       # @param [#to_s] text
       #   The text to parse
       def replace_variables(text)
-        text = text.gsub(/<pid-last-command-started>/, last_command_started.pid.to_s) if text.include? '<pid-last-command-started>'
+        if text.include? '<pid-last-command-started>'
+          text = text.gsub(/<pid-last-command-started>/, last_command_started.pid.to_s)
+        end
 
         text
       end
