@@ -15,10 +15,17 @@ module Aruba
     end
 
     def method_missing(name, *args)
-      fail ArgumentError, 'Options take no argument' if args.count > 0
-      fail UnknownOptionError, %(Option "#{name}" is unknown. Please use only earlier defined options) unless config.key? name
+      if config.key? name
+        raise ArgumentError, 'Options take no argument' if args.any?
 
-      config[name]
+        config[name]
+      else
+        super
+      end
+    end
+
+    def respond_to_missing?(name, _include_private)
+      config.key? name
     end
   end
 end
