@@ -6,7 +6,7 @@ require 'aruba/matchers/command/have_finished_in_time'
 # @!method be_successfuly_executed
 #   This matchers checks if execution of <command> was successful
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if command was not successful
@@ -27,8 +27,12 @@ RSpec::Matchers.define :be_successfully_executed do
 
     expect(@old_actual).to have_exit_status(0)
   end
+
+  failure_message do |_actual|
+    "Expected `#{@actual}` to succeed" \
+      ' but got non-zero exit status and the following output:' \
+      "\n\n#{@old_actual.output}\n"
+  end
 end
 
-if RSpec::Expectations::Version::STRING >= '3.1'
-  RSpec::Matchers.define_negated_matcher :have_failed_running, :be_successfully_executed
-end
+RSpec::Matchers.define_negated_matcher :have_failed_running, :be_successfully_executed
