@@ -4,7 +4,7 @@
 #   @param [Integer] status
 #     The value of the exit status
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if command does not have exit status
@@ -23,16 +23,28 @@ RSpec::Matchers.define :have_exit_status do |expected|
     @old_actual.stop
     @actual = actual.exit_status
 
-    next false unless @old_actual.respond_to? :exit_status
+    unless @old_actual.respond_to? :exit_status
+      raise "Expected #{@old_actual} to respond to #exit_status"
+    end
 
     values_match? expected, @actual
   end
 
   failure_message do |actual|
-    format(%(expected that command "%s" has exit status of "%s", but has "%s".), @old_actual.commandline, expected.to_s, actual.to_s)
+    format(
+      %(expected that command "%s" has exit status of "%s", but has "%s".),
+      @old_actual.commandline,
+      expected.to_s,
+      actual.to_s
+    )
   end
 
   failure_message_when_negated do |actual|
-    format(%(expected that command "%s" does not have exit status of "%s", but has "%s".), @old_actual.commandline, expected.to_s, actual.to_s)
+    format(
+      %(expected that command "%s" does not have exit status of "%s", but has "%s".),
+      @old_actual.commandline,
+      expected.to_s,
+      actual.to_s
+    )
   end
 end
