@@ -4,7 +4,7 @@ require 'rspec/expectations/version'
 #   This matchers checks if <command> run too long. Say the timeout is 10
 #   seconds and it takes <command> to finish in 15. This matchers will succeed.
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if command not to run too long
@@ -24,7 +24,9 @@ RSpec::Matchers.define :have_finished_in_time do
     @old_actual = actual
     @actual     = @old_actual.commandline
 
-    next false unless @old_actual.respond_to? :timed_out?
+    unless @old_actual.respond_to? :timed_out?
+      raise "Expected #{@old_actual} to respond to #timed_out?"
+    end
 
     @old_actual.stop
 
@@ -32,6 +34,4 @@ RSpec::Matchers.define :have_finished_in_time do
   end
 end
 
-if RSpec::Expectations::Version::STRING >= '3.1'
-  RSpec::Matchers.define_negated_matcher :run_too_long, :have_finished_in_time
-end
+RSpec::Matchers.define_negated_matcher :run_too_long, :have_finished_in_time
