@@ -4,7 +4,7 @@ require 'shellwords'
 # @!method be_an_existing_executable
 #   This matchers checks if <file> exists in filesystem
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if file does not exist
@@ -24,14 +24,12 @@ RSpec::Matchers.define :be_an_existing_executable do |_|
   end
 
   failure_message do |actual|
-    format("expected that executable \"%s\" exists", actual)
+    format('expected that executable "%s" exists', actual)
   end
 
   failure_message_when_negated do |actual|
-    format("expected that executable \"%s\" does not exist", actual)
+    format('expected that executable "%s" does not exist', actual)
   end
 end
 
-if RSpec::Expectations::Version::STRING >= '3.0'
-  RSpec::Matchers.alias_matcher :an_existing_executable, :be_an_existing_executable
-end
+RSpec::Matchers.alias_matcher :an_existing_executable, :be_an_existing_executable
