@@ -1,5 +1,4 @@
 require 'rspec/expectations/version'
-
 require 'fileutils'
 
 # @!method have_same_file_content_as(file_name)
@@ -9,7 +8,7 @@ require 'fileutils'
 #     The name of the file which should be compared with the file in the
 #     `expect()`-call.
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if file1 is not equal file2
@@ -31,18 +30,16 @@ RSpec::Matchers.define :have_same_file_content_as do |expected|
     @actual = expand_path(actual)
     @expected = expand_path(expected)
 
-    FileUtils.compare_file(@actual,@expected)
+    FileUtils.compare_file(@actual, @expected)
   end
 
   failure_message do |actual|
-    format("expected that file \"%s\" is the same as file \"%s\".", actual, expected)
+    format('expected that file "%s" is the same as file "%s".', actual, expected)
   end
 
   failure_message_when_negated do |actual|
-    format("expected that file \"%s\" differs from file \"%s\".", actual, expected)
+    format('expected that file "%s" differs from file "%s".', actual, expected)
   end
 end
 
-if RSpec::Expectations::Version::STRING >= '3.0'
-  RSpec::Matchers.alias_matcher :a_file_with_same_content_as, :have_same_file_content_as
-end
+RSpec::Matchers.alias_matcher :a_file_with_same_content_as, :have_same_file_content_as
