@@ -3,7 +3,7 @@ require 'rspec/expectations/version'
 # @!method be_an_absolute_path
 #   This matchers checks if <path> exists in filesystem
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if path is not absolute
@@ -27,10 +27,8 @@ RSpec::Matchers.define :be_an_absolute_path do |_|
   end
 
   failure_message_when_negated do |actual|
-    format("expected that path \"%s\" is not absolute, but it is", actual)
+    format('expected that path "%s" is not absolute, but it is', actual)
   end
 end
 
-if RSpec::Expectations::Version::STRING >= '3.0'
-  RSpec::Matchers.alias_matcher :an_absolute_path, :be_an_absolute_path
-end
+RSpec::Matchers.alias_matcher :an_absolute_path, :be_an_absolute_path
