@@ -3,7 +3,7 @@ require 'rspec/expectations/version'
 # @!method be_an_existing_path
 #   This matchers checks if <path> exists in filesystem
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if path does not exist
@@ -24,14 +24,12 @@ RSpec::Matchers.define :be_an_existing_path do |_|
   end
 
   failure_message do |actual|
-    format("expected that path \"%s\" exists", actual)
+    format('expected that path "%s" exists', actual)
   end
 
   failure_message_when_negated do |actual|
-    format("expected that path \"%s\" does not exist", actual)
+    format('expected that path "%s" does not exist', actual)
   end
 end
 
-if RSpec::Expectations::Version::STRING >= '3.0'
-  RSpec::Matchers.alias_matcher :an_existing_path, :be_an_existing_path
-end
+RSpec::Matchers.alias_matcher :an_existing_path, :be_an_existing_path
