@@ -13,8 +13,8 @@ module Aruba
       #
       # @yield
       #   The block of code which should with local ENV
-      def call(env, &block)
-        old_env = ENV.to_hash.dup
+      def call(env)
+        old_env = Aruba.platform.environment_variables.hash_from_env
 
         ENV.clear
         ENV.update env
