@@ -17,7 +17,7 @@ module Aruba
       def initialize(hash, opts)
         @hash = hash
         @opts = {
-          :sort => true
+          sort: true
         }.merge opts
       end
 
@@ -31,16 +31,8 @@ module Aruba
 
         name_size = longest_key.length
 
-        if RUBY_VERSION < '2'
-          rows = []
-
-          hash.each do |k,v|
-            rows << format("# %-#{name_size}s => %s", k, v)
-          end
-        else
-          rows = hash.each_with_object([]) do |(k,v), a|
-            a << format("# %-#{name_size}s => %s", k, v)
-          end
+        rows = hash.map do |k, v|
+          format("# %-#{name_size}s => %s", k, v)
         end
 
         if opts[:sort] == true
