@@ -6,21 +6,17 @@ module Aruba
   # Platforms
   module Platforms
     # This is a command which should be run
-    class UnixCommandString < SimpleDelegator
-      def initialize(cmd)
-        __setobj__ cmd
+    #
+    # @private
+    class UnixCommandString
+      def initialize(command, *arguments)
+        @command = command
+        @arguments = arguments
       end
 
       # Convert to array
       def to_a
-        [__getobj__]
-      end
-
-      if RUBY_VERSION < '1.9'
-        def to_s
-          __getobj__.to_s
-        end
-        alias inspect to_s
+        [@command, *@arguments]
       end
     end
   end
