@@ -13,7 +13,7 @@ module Aruba
         end
 
         def call(program, path)
-          fail %(Invalid input program "#{program}" and/or path "#{path}".)
+          raise %(Invalid input program "#{program}" and/or path "#{path}".)
         end
       end
 
@@ -23,11 +23,12 @@ module Aruba
           Aruba.platform.absolute_path?(program) || Aruba.platform.relative_command?(program)
         end
 
-        def call(program, path)
+        def call(program, _path)
           # Expand `#path_exts`
           found = Dir[program].first
 
           return File.expand_path(found) if found && Aruba.platform.executable?(found)
+
           nil
         end
       end
@@ -48,7 +49,7 @@ module Aruba
             file = File.join(dir, program)
             # Dir[] doesn't handle backslashes properly, so convert them. Also, if
             # the program name doesn't have an extension, try them all.
-            file = file.tr("\\", "/")
+            file = file.tr('\\', '/')
 
             found = Dir[file].first
 
@@ -95,7 +96,11 @@ module Aruba
       private
 
       def windows_executable_extentions
-        ENV['PATHEXT'] ? format('.{%s}', ENV['PATHEXT'].tr(';', ',').tr('.','')).downcase : '.{exe,com,bat}'
+        if ENV['PATHEXT']
+          format('.{%s}', ENV['PATHEXT'].tr(';', ',').tr('.', '')).downcase
+        else
+          '.{exe,com,bat}'
+        end
       end
     end
   end
