@@ -14,7 +14,7 @@ module Aruba
       attr_reader :exit_status, :environment, :working_directory, :main_class,
                   :io_wait_timeout, :exit_timeout, :startup_wait_time, :stop_signal
 
-      def initialize(cmd, exit_timeout, io_wait_timeout, working_directory,
+      def initialize(cmd, exit_timeout, io_wait_timeout, working_directory, # rubocop:disable Metrics/ParameterLists
                      environment = Aruba.platform.environment_variables.hash_from_env,
                      main_class = nil, stop_signal = nil, startup_wait_time = 0)
         @cmd               = cmd
@@ -135,7 +135,7 @@ module Aruba
       def truncate(string, max_length)
         return string if string.length <= max_length
 
-        string[0, max_length - 1] + ' ...'
+        "#{string[0, max_length - 1]} ..."
       end
     end
   end
