@@ -46,7 +46,7 @@ module Aruba
       # @private
       attr_reader :main_class
 
-      def initialize(cmd, exit_timeout, io_wait_timeout, working_directory,
+      def initialize(cmd, exit_timeout, io_wait_timeout, working_directory, # rubocop:disable Metrics/ParameterLists
                      environment = Aruba.platform.environment_variables.hash_from_env,
                      main_class = nil, stop_signal = nil, startup_wait_time = 0)
         @cmd               = cmd
