@@ -4,16 +4,12 @@ require 'aruba/api'
 RSpec.describe Aruba::Api::Filesystem do
   include_context 'uses aruba API'
 
-  def expand_path(*args)
-    @aruba.expand_path(*args)
-  end
-
   describe '#all_paths' do
     let(:name) { @file_name }
     let(:path) { @file_path }
 
     context 'when file exists' do
-      before :each do
+      before do
         Aruba.platform.write_file(path, '')
       end
 
@@ -24,7 +20,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:name) { 'test_dir' }
       let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
-      before :each do
+      before do
         Aruba.platform.mkdir(path)
       end
 
@@ -41,7 +37,7 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:path) { @file_path }
 
     context 'when file exists' do
-      before :each do
+      before do
         Aruba.platform.write_file(path, '')
       end
 
@@ -52,7 +48,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:name) { 'test_dir' }
       let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
-      before :each do
+      before do
         Aruba.platform.mkdir(path)
       end
 
@@ -69,7 +65,7 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:path) { @file_path }
 
     context 'when file exists' do
-      before :each do
+      before do
         Aruba.platform.write_file(path, '')
       end
 
@@ -80,7 +76,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:name) { 'test_dir' }
       let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
-      before :each do
+      before do
         Aruba.platform.mkdir(path)
       end
 
@@ -98,7 +94,7 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:size) { file_size(name) }
 
     context 'when file exists' do
-      before :each do
+      before do
         File.open(path, 'w') { |f| f.print 'a' }
       end
 
@@ -107,7 +103,8 @@ RSpec.describe Aruba::Api::Filesystem do
 
     context 'when file does not exist' do
       let(:name) { 'non_existing_file' }
-      it { expect { size }.to raise_error ArgumentError }
+
+      it { expect { size }.to raise_error RSpec::Expectations::ExpectationNotMetError }
     end
   end
 
@@ -116,17 +113,18 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:path) { @file_path }
     let(:options) { {} }
 
-    before :each do
+    before do
       @aruba.set_environment_variable 'HOME', File.expand_path(@aruba.aruba.current_directory)
     end
 
     context 'when touching a file that does not exist' do
-      before :each do
+      before do
         @aruba.touch(name, options)
       end
 
       context 'and should be created in an existing directory' do
         it { expect(File.size(path)).to eq 0 }
+
         it_behaves_like 'an existing file'
       end
 
@@ -147,7 +145,7 @@ RSpec.describe Aruba::Api::Filesystem do
 
       context 'and the mtime should be set statically' do
         let(:time) { Time.parse('2014-01-01 10:00:00') }
-        let(:options) { { :mtime => Time.parse('2014-01-01 10:00:00') } }
+        let(:options) { { mtime: Time.parse('2014-01-01 10:00:00') } }
 
         it_behaves_like 'an existing file'
         it { expect(File.mtime(path)).to eq time }
@@ -155,7 +153,10 @@ RSpec.describe Aruba::Api::Filesystem do
 
       context 'and multiple file names are given' do
         let(:name) { %w(file1 file2 file3) }
-        let(:path) { %w(file1 file2 file3).map { |p| File.join(@aruba.aruba.current_directory, p) } }
+        let(:path) do
+          %w(file1 file2 file3).map { |p| File.join(@aruba.aruba.current_directory, p) }
+        end
+
         it_behaves_like 'an existing file'
       end
     end
@@ -171,7 +172,7 @@ RSpec.describe Aruba::Api::Filesystem do
 
       context 'and the mtime should be set statically' do
         let(:time) { Time.parse('2014-01-01 10:00:00') }
-        let(:options) { { :mtime => Time.parse('2014-01-01 10:00:00') } }
+        let(:options) { { mtime: Time.parse('2014-01-01 10:00:00') } }
 
         it_behaves_like 'an existing directory'
         it { Array(path).each { |p| expect(File.mtime(p)).to eq time } }
@@ -183,11 +184,11 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:name) { @file_name }
     let(:path) { File.expand_path(File.join(@aruba.aruba.current_directory, name)) }
 
-    context 'when given an absolute path' do
+    context 'when is absolute path' do
       it { expect(@aruba).to be_absolute(path) }
     end
 
-    context 'when given a relative path' do
+    context 'when is relative path' do
       it { expect(@aruba).not_to be_absolute(name) }
     end
   end
@@ -211,7 +212,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:path) { @file_path }
 
       context 'when it exists' do
-        before :each do
+        before do
           Aruba.platform.write_file(path, '')
         end
 
@@ -228,7 +229,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
       context 'when it exists' do
-        before :each do
+        before do
           Aruba.platform.mkdir(path)
         end
 
@@ -247,7 +248,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:path) { @file_path }
 
       context 'when it exists' do
-        before :each do
+        before do
           Aruba.platform.write_file(path, '')
         end
 
@@ -264,14 +265,14 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
       context 'when it exists' do
-        before :each do
+        before do
           Aruba.platform.mkdir(path)
         end
 
         it { expect(@aruba).not_to be_file(name) }
       end
 
-      context 'when it does not exist' do
+      context 'when does not exist' do
         it { expect(@aruba).not_to be_file(name) }
       end
     end
@@ -283,14 +284,14 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:path) { @file_path }
 
       context 'when it exists' do
-        before :each do
+        before do
           Aruba.platform.write_file(path, '')
         end
 
         it { expect(@aruba).not_to be_directory(name) }
       end
 
-      context 'when it does not exist' do
+      context 'when does not exist' do
         it { expect(@aruba).not_to be_directory(name) }
       end
     end
@@ -300,7 +301,7 @@ RSpec.describe Aruba::Api::Filesystem do
       let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
       context 'when it exists' do
-        before :each do
+        before do
           Aruba.platform.mkdir(path)
         end
 
@@ -320,9 +321,8 @@ RSpec.describe Aruba::Api::Filesystem do
     context 'when source is existing' do
       context 'when destination is non-existing' do
         context 'when source is file' do
-          before(:each) { create_test_files(source) }
-
-          before :each do
+          before do
+            create_test_files(source)
             @aruba.copy source, destination
           end
 
@@ -332,12 +332,14 @@ RSpec.describe Aruba::Api::Filesystem do
 
           context 'when source is contains "~" in path' do
             let(:source) { '~/file.txt' }
+
             it { expect(destination).to be_an_existing_file }
           end
 
           context 'when source is fixture' do
             let(:source) { '%/copy/file.txt' }
             let(:destination) { 'file.txt' }
+
             it { expect(destination).to be_an_existing_file }
           end
 
@@ -354,11 +356,8 @@ RSpec.describe Aruba::Api::Filesystem do
           let(:source) { 'src.d' }
           let(:destination) { 'dst.d' }
 
-          before :each do
+          before do
             Aruba.platform.mkdir(File.join(@aruba.aruba.current_directory, source))
-          end
-
-          before :each do
             @aruba.copy source, destination
           end
 
@@ -377,49 +376,61 @@ RSpec.describe Aruba::Api::Filesystem do
 
       context 'when destination is existing' do
         context 'when source is list of files' do
-          before(:each) { create_test_files(source) }
+          before { create_test_files(source) }
 
           context 'when destination is directory' do
             let(:source) { %w(file1.txt file2.txt file3.txt) }
             let(:destination) { 'file.d' }
             let(:destination_files) { source.map { |s| File.join(destination, s) } }
 
-            before :each do
+            before do
               Aruba.platform.mkdir(File.join(@aruba.aruba.current_directory, destination))
-            end
-
-            before :each do
               @aruba.copy source, destination
             end
 
-            it { source.each { |s| expect(destination_files).to all be_an_existing_file } }
+            it { expect(destination_files).to all be_an_existing_file }
           end
 
           context 'when destination is not a directory' do
             let(:source) { %w(file1.txt file2.txt file3.txt) }
             let(:destination) { 'file.txt' }
+            let(:error_message) { 'Multiples sources can only be copied to a directory' }
 
-            before(:each) { create_test_files(destination) }
+            before { create_test_files(destination) }
 
-            it { expect { @aruba.copy source, destination }.to raise_error ArgumentError, "Multiples sources can only be copied to a directory" }
+            it 'raises an appropriate error' do
+              expect { @aruba.copy source, destination }
+                .to raise_error ArgumentError, error_message
+            end
           end
 
           context 'when a source is the same like destination' do
             let(:source) { 'file1.txt' }
             let(:destination) { 'file1.txt' }
 
-            before(:each) { create_test_files(source) }
+            before { create_test_files(source) }
 
-            # rubocop:disable Metrics/LineLength
-            it { expect { @aruba.copy source, destination }.to raise_error ArgumentError, %(same file: #{File.expand_path(File.join(@aruba.aruba.current_directory, source))} and #{File.expand_path(File.join(@aruba.aruba.current_directory, destination))}) }
-            # rubocop:enable Metrics/LineLength
+            it 'raises an appropriate error' do
+              src_path = File.expand_path(File.join(@aruba.aruba.current_directory, source))
+              dest_path = File.expand_path(File.join(@aruba.aruba.current_directory,
+                                                     destination))
+              expected_message = %(same file: #{src_path} and #{dest_path})
+              expect { @aruba.copy source, destination }
+                .to raise_error ArgumentError, expected_message
+            end
           end
 
           context 'when a fixture is destination' do
             let(:source) { '%/copy/file.txt' }
             let(:destination) { '%/copy/file.txt' }
+            let(:error_message) do
+              "Using a fixture as destination (#{destination}) is not supported"
+            end
 
-            it { expect { @aruba.copy source, destination }.to raise_error ArgumentError, "Using a fixture as destination (#{destination}) is not supported" }
+            it 'raises an appropriate error' do
+              expect { @aruba.copy source, destination }
+                .to raise_error ArgumentError, error_message
+            end
           end
         end
       end
@@ -430,7 +441,7 @@ RSpec.describe Aruba::Api::Filesystem do
     end
   end
 
-  context '#write_file' do
+  describe '#write_file' do
     it 'writes file' do
       @aruba.write_file(@file_name, '')
 
@@ -438,14 +449,14 @@ RSpec.describe Aruba::Api::Filesystem do
     end
   end
 
-  context '#write_fixed_size_file' do
-    it "should write a fixed sized file" do
+  describe '#write_fixed_size_file' do
+    it 'writes a fixed sized file' do
       @aruba.write_fixed_size_file(@file_name, @file_size)
       expect(File.exist?(@file_path)).to eq true
       expect(File.size(@file_path)).to eq @file_size
     end
 
-    it "works with ~ in path name" do
+    it 'works with ~ in path name' do
       file_path = File.join('~', random_string)
 
       @aruba.with_environment 'HOME' => File.expand_path(aruba.current_directory) do
@@ -459,33 +470,28 @@ RSpec.describe Aruba::Api::Filesystem do
 
   describe '#chmod' do
     def actual_permissions
-      format("%o" , File::Stat.new(file_path).mode )[-4,4]
+      format('%o', File::Stat.new(file_path).mode)[-4, 4]
     end
 
     let(:file_name) { @file_name }
     let(:file_path) { @file_path }
-    let(:permissions) { '0655' }
+    let(:permissions) { '0644' }
 
-    before :each do
+    before do
       @aruba.set_environment_variable 'HOME', File.expand_path(@aruba.aruba.current_directory)
-    end
-
-    before(:each) do
-      File.open(file_path, 'w') { |f| f << "" }
-    end
-
-    before(:each) do
+      File.open(file_path, 'w') { |f| f << '' }
       @aruba.chmod(permissions, file_name)
     end
 
     context 'when file exists' do
       context 'and permissions are given as string' do
-        it { expect(actual_permissions).to eq('0655') }
+        it { expect(actual_permissions).to eq('0644') }
       end
 
       context 'and permissions are given as octal number' do
-        let(:permissions) { 0o655 }
-        it { expect(actual_permissions).to eq('0655') }
+        let(:permissions) { 0o644 }
+
+        it { expect(actual_permissions).to eq('0644') }
       end
 
       context 'and path has ~ in it' do
@@ -493,44 +499,64 @@ RSpec.describe Aruba::Api::Filesystem do
         let(:file_name) { File.join('~', path) }
         let(:file_path) { File.join(@aruba.aruba.current_directory, path) }
 
-        it { expect(actual_permissions).to eq('0655') }
+        it { expect(actual_permissions).to eq('0644') }
       end
     end
   end
 
-  context "#with_file_content" do
-    before :each do
-      @aruba.write_file(@file_name, "foo bar baz")
+  describe '#with_file_content' do
+    before do
+      @aruba.write_file(@file_name, 'foo bar baz')
     end
 
-    it "passes the given file's full content to the given block" do
+    it "checks the given file's full content against the expectations in the passed block" do
       @aruba.with_file_content @file_name do |full_content|
-        expect(full_content).to eq "foo bar baz"
+        expect(full_content).to eq 'foo bar baz'
       end
     end
 
-    it "works with ~ in path name" do
+    it 'works with ~ in path name' do
       file_path = File.join('~', random_string)
 
       @aruba.with_environment 'HOME' => File.expand_path(aruba.current_directory) do
-        @aruba.write_file(file_path, "foo bar baz")
+        @aruba.write_file(file_path, 'foo bar baz')
 
         @aruba.with_file_content file_path do |full_content|
-          expect(full_content).to eq "foo bar baz"
+          expect(full_content).to eq 'foo bar baz'
         end
       end
     end
+
+    context "checking the file's content against the expectations in the block" do
+      it 'is successful when the inner expectations match' do
+        expect do
+          @aruba.with_file_content @file_name do |full_content|
+            expect(full_content).to     match(/foo/)
+            expect(full_content).not_to match(/zoo/)
+          end
+        end.not_to raise_error
+      end
+
+      it "raises ExpectationNotMetError when the inner expectations don't match" do
+        expect do
+          @aruba.with_file_content @file_name do |full_content|
+            expect(full_content).to     match(/zoo/)
+            expect(full_content).not_to match(/foo/)
+          end
+        end.to raise_error RSpec::Expectations::ExpectationNotMetError
+      end
+    end
   end
 
   describe '#create_directory' do
-    before(:each) do
+    before do
       @directory_name = 'test_dir'
       @directory_path = File.join(@aruba.aruba.current_directory, @directory_name)
     end
 
     it 'creates a directory' do
       @aruba.create_directory @directory_name
-      expect(File.exist?(File.expand_path(@directory_path))).to be_truthy
+      expect(File).to exist(File.expand_path(@directory_path))
     end
   end
 
@@ -539,7 +565,7 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:path) { File.join(@aruba.aruba.current_directory, name) }
     let(:content) { 'asdf' }
 
-    before :each do
+    before do
       @aruba.set_environment_variable 'HOME', File.expand_path(@aruba.aruba.current_directory)
     end
 
@@ -549,7 +575,7 @@ RSpec.describe Aruba::Api::Filesystem do
 
     context 'when it exists' do
       context 'when file' do
-        before :each do
+        before do
           File.open(File.expand_path(path), 'w') { |f| f << content }
         end
 
@@ -559,11 +585,13 @@ RSpec.describe Aruba::Api::Filesystem do
 
         context 'when binary file' do
           let(:content) { "\u0000" }
+
           it { expect(@aruba.read(name)).to eq [content] }
         end
 
         context 'when is empty file' do
           let(:content) { '' }
+
           it { expect(@aruba.read(name)).to eq [] }
         end
 
@@ -580,7 +608,7 @@ RSpec.describe Aruba::Api::Filesystem do
         let(:name) { 'test.d' }
 
         before do
-          Array(path).each { |p| Aruba.platform.mkdir p }
+          Aruba.platform.mkdir path
         end
 
         it { expect { @aruba.read(name) }.to raise_error ArgumentError }
@@ -593,7 +621,7 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:content) { %w(subdir.1.d subdir.2.d) }
     let(:path) { File.join(@aruba.aruba.current_directory, name) }
 
-    before :each do
+    before do
       @aruba.set_environment_variable 'HOME', File.expand_path(@aruba.aruba.current_directory)
     end
 
@@ -605,7 +633,7 @@ RSpec.describe Aruba::Api::Filesystem do
       context 'when file' do
         let(:name) { 'test.txt' }
 
-        before :each do
+        before do
           File.open(File.expand_path(path), 'w') { |f| f << content }
         end
 
@@ -616,8 +644,8 @@ RSpec.describe Aruba::Api::Filesystem do
 
       context 'when directory' do
         before do
-          Array(path).each { |p| Aruba.platform.mkdir p }
-          Array(content).each { |p| Aruba.platform.mkdir File.join(path, p) }
+          Aruba.platform.mkdir path
+          Array(content).each { |it| Aruba.platform.mkdir File.join(path, it) }
         end
 
         context 'when has subdirectories' do
@@ -642,6 +670,7 @@ RSpec.describe Aruba::Api::Filesystem do
 
         context 'when has no subdirectories' do
           let(:content) { [] }
+
           it { expect(@aruba.list(name)).to eq [] }
         end
       end
@@ -653,14 +682,14 @@ RSpec.describe Aruba::Api::Filesystem do
     let(:path) { File.join(@aruba.aruba.current_directory, name) }
     let(:options) { {} }
 
-    before :each do
+    before do
       @aruba.set_environment_variable 'HOME', File.expand_path(@aruba.aruba.current_directory)
     end
 
     context 'when given a file' do
       context 'when it exists' do
         before do
-          Array(path).each { |p| File.open(File.expand_path(p), 'w') { |f| f << "" } }
+          Array(path).each { |it| File.open(File.expand_path(it), 'w') { |f| f << '' } }
 
           @aruba.remove(name, options)
         end
@@ -670,16 +699,16 @@ RSpec.describe Aruba::Api::Filesystem do
         end
 
         context 'when are multiple files' do
-          let(:file_name) { %w(file1 file2 file3) }
-          let(:file_path) { %w(file1 file2 file3).map { |p| File.join(@aruba.aruba.current_directory, p) } }
+          let(:name) { %w(file1 file2 file3) }
+          let(:path) { name.map { |it| File.join(@aruba.aruba.current_directory, it) } }
 
           it_behaves_like 'a non-existing file'
         end
 
         context 'when path contains ~' do
           let(:string) { random_string }
-          let(:file_name) { File.join('~', string) }
-          let(:file_path) { File.join(@aruba.aruba.current_directory, string) }
+          let(:name) { File.join('~', string) }
+          let(:path) { File.join(@aruba.aruba.current_directory, string) }
 
           it_behaves_like 'a non-existing file'
         end
@@ -690,8 +719,8 @@ RSpec.describe Aruba::Api::Filesystem do
           @aruba.remove(name, options)
         end
 
-        context 'when forced to delete file' do
-          let(:options) { { :force => true } }
+        context 'when forced to delete the file' do
+          let(:options) { { force: true } }
 
           it_behaves_like 'a non-existing file'
         end
@@ -703,10 +732,7 @@ RSpec.describe Aruba::Api::Filesystem do
 
       context 'when it exists' do
         before do
-          Array(path).each { |p| Aruba.platform.mkdir p }
-        end
-
-        before :each do
+          Array(path).each { |it| Aruba.platform.mkdir it }
           @aruba.remove(name, options)
         end
 
@@ -715,28 +741,28 @@ RSpec.describe Aruba::Api::Filesystem do
         end
 
         context 'when are multiple directorys' do
-          let(:directory_name) { %w(directory1 directory2 directory3) }
-          let(:directory_path) { %w(directory1 directory2 directory3).map { |p| File.join(@aruba.aruba.current_directory, p) } }
+          let(:name) { %w(directory1 directory2 directory3) }
+          let(:path) { name.map { |it| File.join(@aruba.aruba.current_directory, it) } }
 
           it_behaves_like 'a non-existing directory'
         end
 
         context 'when path contains ~' do
           let(:string) { random_string }
-          let(:directory_name) { File.join('~', string) }
-          let(:directory_path) { File.join(@aruba.aruba.current_directory, string) }
+          let(:name) { File.join('~', string) }
+          let(:path) { File.join(@aruba.aruba.current_directory, string) }
 
           it_behaves_like 'a non-existing directory'
         end
       end
 
       context 'when it does not exist' do
-        before :each do
+        before do
           @aruba.remove(name, options)
         end
 
-        context 'when is forced to delete directory' do
-          let(:options) { { :force => true } }
+        context 'when forced to delete the directory' do
+          let(:options) { { force: true } }
 
           it_behaves_like 'a non-existing directory'
         end
