@@ -6,7 +6,7 @@ RSpec.describe Aruba::InConfigWrapper do
   let(:config) { {} }
 
   context 'when option is defined' do
-    before :each do
+    before do
       config[:opt] = true
     end
 
@@ -15,11 +15,16 @@ RSpec.describe Aruba::InConfigWrapper do
     end
 
     context 'when one tries to pass arguments to option' do
-      it { expect{ wrapper.opt('arg') }.to raise_error ArgumentError, 'Options take no argument' }
+      it {
+        expect { wrapper.opt('arg') }
+          .to raise_error ArgumentError, 'Options take no argument'
+      }
     end
   end
 
   context 'when option is not defined' do
-    it { expect{ wrapper.opt }.to raise_error ArgumentError, 'Option "opt" is unknown. Please use only earlier defined options' }
+    it 'raises an error' do
+      expect { wrapper.opt }.to raise_error NoMethodError
+    end
   end
 end
