@@ -4,14 +4,13 @@ require 'fileutils'
 
 RSpec.describe 'Directory Matchers' do
   include_context 'uses aruba API'
-  include_context 'needs to expand paths'
 
   describe 'to_be_an_existing_directory' do
     let(:name) { 'test.d' }
     let(:path) { @aruba.expand_path(name) }
 
     context 'when directory exists' do
-      before :each do
+      before do
         FileUtils.mkdir_p path
       end
 
@@ -29,11 +28,8 @@ RSpec.describe 'Directory Matchers' do
     let(:content) { %w(subdir.1.d subdir.2.d) }
 
     context 'when directory exists' do
-      before :each do
+      before do
         FileUtils.mkdir_p path
-      end
-
-      before :each do
         Array(content).each { |p| Dir.mkdir File.join(path, p) }
       end
 
