@@ -1,8 +1,10 @@
-require 'aruba/event_bus'
+require 'spec_helper'
 
 module Events
   class TestEvent; end
+
   class AnotherTestEvent; end
+
   module MalformedTestEvent; end
 end
 
@@ -17,21 +19,22 @@ describe Aruba::EventBus do
 
   let(:name_resolver) { instance_double('Events::NameResolver') }
 
-  let!(:event_klass) { Events::TestEvent }
-  let!(:event_name) { event_klass }
-  let!(:event_instance) { Events::TestEvent.new }
+  let(:event_klass) { Events::TestEvent }
+  let(:event_name) { event_klass }
+  let(:event_instance) { Events::TestEvent.new }
 
-  let!(:another_event_klass) { Events::AnotherTestEvent }
-  let!(:another_event_name) { another_event_klass }
-  let!(:another_event_instance) { Events::AnotherTestEvent.new }
+  let(:another_event_klass) { Events::AnotherTestEvent }
+  let(:another_event_name) { another_event_klass }
+  let(:another_event_instance) { Events::AnotherTestEvent.new }
 
   describe '#notify' do
-    before(:each) do
-      allow(name_resolver).to receive(:transform).with(event_name).and_return(event_klass)
+    before do
+      allow(name_resolver)
+        .to receive(:transform).with(event_name).and_return(event_klass)
     end
 
-    context 'when subscriber to event, the block is called and get\'s an instance of the event passed as payload' do
-      before :each do
+    context 'when subscribed to the event' do
+      before do
         bus.register(event_klass) do |event|
           @received_payload = event
         end
@@ -39,11 +42,13 @@ describe Aruba::EventBus do
         bus.notify event_instance
       end
 
-      it { expect(@received_payload).to eq(event_instance) }
+      it 'calls the block with an instance of the event passed as payload' do
+        expect(@received_payload).to eq(event_instance)
+      end
     end
 
     context 'when not subscriber to event' do
-      before :each do
+      before do
         @received_payload = false
         bus.register(event_klass) { @received_payload = true }
         bus.notify another_event_instance
@@ -53,11 +58,11 @@ describe Aruba::EventBus do
     end
 
     context 'when event is not an instance of event class' do
-      let!(:event_name) { :test_event }
+      let(:event_name) { :test_event }
       let(:received_payload) { [] }
 
-      before :each do
-        bus.register(event_name, proc {})
+      before do
+        bus.register(event_name, proc { nil })
       end
 
       it { expect { bus.notify event_klass }.to raise_error Aruba::NoEventError }
@@ -65,15 +70,16 @@ describe Aruba::EventBus do
   end
 
   describe '#register' do
-    before(:each) do
-      allow(name_resolver).to receive(:transform).with(event_name).and_return(event_klass)
+    before do
+      allow(name_resolver)
+        .to receive(:transform).with(event_name).and_return(event_klass)
     end
 
     context 'when valid subscriber' do
       context 'when multiple instances are given' do
         let(:received_events) { [] }
 
-        before :each do
+        before do
           bus.register(Events::TestEvent) do |event|
             received_events << event
           end
@@ -89,10 +95,10 @@ describe Aruba::EventBus do
       end
 
       context 'when is string' do
-        let!(:event_name) { event_klass.to_s }
+        let(:event_name) { event_klass.to_s }
         let(:received_payload) { [] }
 
-        before :each do
+        before do
           bus.register(event_klass.to_s) do |event|
             received_payload << event
           end
@@ -103,11 +109,11 @@ describe Aruba::EventBus do
         it { expect(received_payload).to include event_instance }
       end
 
-      context 'when is symbol and event is defined in the default namespace given to NameResolver.new' do
-        let!(:event_name) { :test_event }
+      context 'when is symbol and event is defined in the default namespace' do
+        let(:event_name) { :test_event }
         let(:received_payload) { [] }
 
-        before :each do
+        before do
           bus.register(event_name) do |event|
             received_payload << event
           end
@@ -121,11 +127,9 @@ describe Aruba::EventBus do
 
     context 'when valid custom handler' do
       context 'when single event class' do
-        before(:each) do
-          allow(name_resolver).to receive(:transform).with(event_name).and_return(event_klass)
-        end
-
-        before :each do
+        before do
+          allow(name_resolver)
+            .to receive(:transform).with(event_name).and_return(event_klass)
           bus.register(event_klass, MyHandler.new)
         end
 
@@ -133,12 +137,11 @@ describe Aruba::EventBus do
       end
 
       context 'when list of event classes' do
-        before(:each) do
-          allow(name_resolver).to receive(:transform).with(event_name).and_return(event_klass)
-          allow(name_resolver).to receive(:transform).with(another_event_name).and_return(another_event_klass)
-        end
-
-        before :each do
+        before do
+          allow(name_resolver)
+            .to receive(:transform).with(event_name).and_return(event_klass)
+          allow(name_resolver)
+            .to receive(:transform).with(another_event_name).and_return(another_event_klass)
           bus.register([event_klass, another_event_klass], MyHandler.new)
         end
 
@@ -148,11 +151,16 @@ describe Aruba::EventBus do
     end
 
     context 'when malformed custom handler' do
-      it { expect { bus.register(event_klass, MyMalformedHandler.new) }.to raise_error ArgumentError }
+      it 'raises an ArgumentError' do
+        expect { bus.register(event_klass, MyMalformedHandler.new) }
+          .to raise_error ArgumentError
+      end
     end
 
     context 'when no handler is given' do
-      it { expect { bus.register(event_klass) }.to raise_error ArgumentError }
+      it 'raises an ArgumentError' do
+        expect { bus.register(event_klass) }.to raise_error ArgumentError
+      end
     end
   end
 end
