@@ -1,4 +1,4 @@
-$LOAD_PATH << ::File.expand_path('../../lib', __FILE__)
+$LOAD_PATH << ::File.expand_path('../lib', __dir__)
 
 unless RUBY_PLATFORM.include?('java')
   require 'simplecov'
@@ -11,5 +11,5 @@ require 'bundler'
 Bundler.require
 
 # Loading support files
-Dir.glob(::File.expand_path('../support/*.rb', __FILE__)).each { |f| require_relative f }
-Dir.glob(::File.expand_path('../support/**/*.rb', __FILE__)).each { |f| require_relative f }
+Dir.glob(::File.expand_path('support/*.rb', __dir__)).each { |f| require_relative f }
+Dir.glob(::File.expand_path('support/**/*.rb', __dir__)).each { |f| require_relative f }
