@@ -6,6 +6,9 @@ RSpec.configure do |config|
 
   config.run_all_when_everything_filtered = true
 
+  config.example_status_persistence_file_path = 'spec/examples.txt'
+  config.profile_examples = 10
+
   config.expect_with :rspec do |c|
     c.syntax = :expect
   end
