@@ -16,12 +16,17 @@ module SpecHelpers
     #   stream = capture(:stderr) { system('echo error 1>&2') }
     #   stream # => "error\n"
     def capture(stream)
-      stream = stream.to_s
-      captured_stream = Tempfile.new(stream)
+      captured_stream = Tempfile.new(stream.to_s)
 
-      # rubocop:disable Lint/Eval
-      stream_io = eval("$#{stream}")
-      # rubocop:enable Lint/Eval
+      stream_io = case stream
+                  when :stdout
+                    $stdout
+                  when :stderr
+                    $stderr
+                  else
+                    raise ArgumentError,
+                          "Expected stream to be :stdout or :stderr, got #{stream.inspect}"
+                  end
 
       origin_stream = stream_io.dup
       stream_io.reopen(captured_stream)
@@ -29,7 +34,7 @@ module SpecHelpers
       yield
 
       stream_io.rewind
-      return captured_stream.read
+      captured_stream.read
     ensure
       captured_stream.close
       captured_stream.unlink
